/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using NAnt.Core.Types;

namespace TopCoder.Test.Framework.Servers
{

    /// <summary>
    /// <p>
    /// This class is derived from Server class and is the base class
    /// for all classes representing an application server to be used while running tests.
    /// </p>
    /// <p>
    /// Supported options:<br/>
    /// DEMPLOYMENT_DIR - specifies the directory the application should be deployed to.<br/>
    /// </p>
    /// <p>
    /// The parent class is mutable, so this class is mutable, i.e. not thread-safe.
    /// </p>
    /// </summary>
    ///
    /// <author>real_vg</author>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    public abstract class ApplicationServer : Server
    {

        /// <summary>
        /// This string constanst represents the name (key) of the option, the derived classes
        /// should use for getting the directory the application should be deployed to.
        /// Note, that the derived classes
        /// can treat options in any way they like to do.
        /// The most simple way this option can be used is
        /// copying the files specified by the SourceFiles property to the directory
        /// specified by this option.
        /// </summary>
        public static readonly string DEPLOYMENT_DIR = "deployment_dir";

        /// <summary>
        /// This property provides the read access to the option, the derived classes
        /// should use for getting the directory the application should be deployed to.
        /// Note, that the derived classes
        /// can treat options in any way they like to do.
        /// The most simple way this option can be used is
        /// copying the files specified by the SourceFiles property to the directory
        /// specified by this option.
        /// </summary>
        ///
        /// <value>The directory the application should be deployed to.</value>
        /// <exception cref="ServerException">If deployment_dir option is missing, or Options is null.</exception>
        public string DeploymentDirectory
        {
            get
            {
                return GetOption(DEPLOYMENT_DIR);
            }
        }

        /// <summary>
        /// <p>
        /// Creates an instance of class.
        /// </p>
        /// </summary>
        protected ApplicationServer() : base()
        {
            // Just call the constructor of the superclass.
        }
    }
}
