/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using NAnt.NUnit2.Tasks;
using NUnit.Framework;
using TopCoder.Test.Framework.Servers;
using NAnt.Core;
using System.Xml;

namespace TopCoder.Test.Framework
{

    /// <summary>
    /// Demo for Test Framework component.
    /// This Demo will should how to use Test Framework to run NUnit task at runtime.
    /// Refer to testfiles/demo.xml for how to run it under nant.
    /// </summary>
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class DemoTest
    {

        /// <summary>
        /// The demo task.
        /// </summary>
        private const string DEMO_TASK = "../../test_files/demo_task.xml";

        /// <summary>
        /// The demo server.
        /// </summary>
        private const string DEMO_SERVER = "../../test_files/demo_server.xml";

        /// <summary>
        /// Cleans up the test environment.
        /// </summary>
        [TearDown]
        protected void TearDown()
        {
            TestFrameworkTestHelper.DeleteFile("log/HelloWorld.Tests.dll-results.txt");
        }

        /// <summary>
        /// Demo for ServerAppTestTask class.
        /// The helloworld web application is used in this demo
        /// </summary>
        [Test]
        public void TestServerAppTestTaskDemo()
        {


            // load the task element
            XmlDocument document = new XmlDocument();
            document.Load(DEMO_TASK);
            XmlNode node = document.DocumentElement["serverapptest"];

            // load the task instance from the xml node
            ServerAppTestTask task = new ServerAppTestTask();
            task.Project = new Project(DEMO_TASK, Level.Error);
            task.Initialize(node);

            // exectue the task.
            task.Execute();

        }

        /// <summary>
        /// Demo for Server class.
        /// The helloworld web application is used in this demo
        /// </summary>
        [Test]
        public void TestServerDemo()
        {

            // load the server element
            XmlDocument document = new XmlDocument();
            document.Load(DEMO_SERVER);
            XmlNode node = document.DocumentElement["server"];

            // load the server element instance from the xml node
            ServerElement serverElement = new ServerElement();
            serverElement.Project = new Project(DEMO_SERVER, Level.Error);
            serverElement.Initialize(node);

            // create the server instance from server element
            Server server = serverElement.GetServerInstance();

            // we should initialize at first and then start up the server
            server.InitData();
            server.StartUp();

            // we can do some testing here.

            // after testing finished, we should shut down at first and then clean up the data
            server.ShutDown();
            server.CleanUpData();

        }
    }

}
