/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using NAnt.NUnit2.Tasks;
using NUnit.Framework;
using TopCoder.Test.Framework.Servers;
namespace TopCoder.Test.Framework
{

    /// <summary>
    /// Unit test class for <c>ServerAppTestTask</c> class.
    /// </summary>
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class ServerAppTestTaskTest
    {

        /// <summary>
        /// Private <c>ServerAppTestTask</c> variable used for test.
        /// </summary>
        private ServerAppTestTask task = null;

        /// <summary>
        /// Sets up the test environment. A valid <c>ServerAppTestTask</c> object is created.
        /// </summary>
        [SetUp]
        protected void SetUp()
        {
            TestFrameworkTestHelper.StopService();
            task = new ServerAppTestTask();
        }

        /// <summary>
        /// Cleans up the test environment. The <c>ServerAppTestTask</c> object is disposed.
        /// </summary>
        [TearDown]
        protected void TearDown()
        {

            TestFrameworkTestHelper.DeleteFile("deploy/HelloWorld.aspx");
            TestFrameworkTestHelper.DeleteFile("deploy/subdir/HelloWorld.aspx");
            TestFrameworkTestHelper.DeleteFile("log/HelloWorld.aspx");
        }

        /// <summary>
        /// Tests accuracy of constructor <c>ServerAppTestTask()</c> of <c>ServerAppTestTask</c> class.
        /// The created object should not be null.
        /// The fields should be initialized correctly.
        /// </summary>
        [Test]
        public void TestServerAppTestTaskAccuracy()
        {
            Assert.IsNull(task.Servers, "Servers should be null.");
            Assert.IsNotNull(task, "The created object should not be null.");
        }

        /// <summary>
        /// Tests inheritance of constructor <c>ServerAppTestTask()</c> of <c>ServerAppTestTask</c> class.
        /// <c>ServerAppTestTask</c> class should be inherited from <c>NUnit2Task</c> class.
        /// </summary>
        [Test]
        public void TestServerAppTestTaskInheritance()
        {
            Assert.IsTrue(((object)task) is NUnit2Task,
                "ServerAppTestTask class should be inherited from NUnit2Task class.");
        }


        /// <summary>
        /// Tests accuracy of <c>Servers</c> getter property of <c>ServerAppTestTask</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestServersGetterAccuracyNull()
        {
            Assert.IsNull(task.Servers, "Servers should be null.");
        }


        /// <summary>
        /// Tests accuracy of <c>Servers</c> getter property of <c>ServerAppTestTask</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestServersGetterAccuracyNotNull()
        {
            task.Servers = new ServerElement[] { new ServerElement() };

            Assert.AreEqual(1, task.Servers.Length, "Servers should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Servers</c> setter property of <c>ServerAppTestTask</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestServersSetterAccuracyNull()
        {
            task.Servers = null;
            Assert.IsNull(task.Servers, "Servers should be null.");
        }


        /// <summary>
        /// Tests accuracy of <c>Servers</c> setter property of <c>ServerAppTestTask</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestServersSetterAccuracyNotNull()
        {
            task.Servers = new ServerElement[] { new ServerElement() };

            Assert.AreEqual(1, task.Servers.Length, "Servers should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>ExecuteTask()</c> method of <c>ServerAppTestTask</c> class.
        /// Use a helloworld web application to test.
        /// </summary>
        [Test]
        public void TestExecuteTaskAccuracy()
        {
            task = TestFrameworkTestHelper.LoadServerAppTestTask("task1.xml");
            task.Execute();
            Assert.IsTrue(TestFrameworkTestHelper.CheckLog(), "Helloworld test failed.");
        }

        /// <summary>
        /// Tests accuracy of <c>ExecuteTask()</c> method of <c>ServerAppTestTask</c> class.
        /// Tests multi-server.
        /// </summary>
        [Test]
        public void TestExecuteTaskAccuracyMultiServer()
        {
            task = TestFrameworkTestHelper.LoadServerAppTestTask("task2.xml");
            task.Execute();
            // check whether the test passed
            Assert.IsTrue(TestFrameworkTestHelper.CheckLog(), "Helloworld test failed.");

            // check whether database server was initialized
            foreach (ServerElement element in task.Servers)
            {
                Server server = element.GetServerInstance();
                if (server is MockDatabaseServer)
                {
                    Assert.IsTrue((server as MockDatabaseServer).IsCleanUpData, "Wrong IsCleanUpDate property");
                    Assert.IsTrue((server as MockDatabaseServer).IsInitData, "Wrong IsInitDate property");
                    Assert.IsTrue((server as MockDatabaseServer).IsShutDown, "Wrong IsShutDown property");
                    Assert.IsTrue((server as MockDatabaseServer).IsStartUp, "Wrong IsStartUp property");
                }
            }
        }

        /// <summary>
        /// Tests <c>ExecuteTask()</c> method with invalid server.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ServerTaskException))]
        public void TestExecuteTaskInvalidServer1()
        {
            TestFrameworkTestHelper.LoadServerAppTestTask("invalid_task1.xml").Execute();
        }

        /// <summary>
        /// Tests <c>ExecuteTask()</c> method with invalid server.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ServerTaskException))]
        public void TestExecuteTaskInvalidServer2()
        {
            TestFrameworkTestHelper.LoadServerAppTestTask("invalid_task2.xml").Execute();
        }

        /// <summary>
        /// Tests <c>ExecuteTask()</c> method with invalid server.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ServerTaskException))]
        public void TestExecuteTaskInvalidServer3()
        {
            TestFrameworkTestHelper.LoadServerAppTestTask("invalid_task3.xml").Execute();
        }

        /// <summary>
        /// Tests <c>ExecuteTask()</c> method with invalid server.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ServerTaskException))]
        public void TestExecuteTaskInvalidServer4()
        {
            TestFrameworkTestHelper.LoadServerAppTestTask("invalid_task4.xml").Execute();
        }

        /// <summary>
        /// Tests <c>ExecuteTask()</c> method with invalid server.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ServerTaskException))]
        public void TestExecuteTaskInvalidServer5()
        {
            TestFrameworkTestHelper.LoadServerAppTestTask("invalid_task5.xml").Execute();
        }

        /// <summary>
        /// Tests <c>ExecuteTask()</c> method with invalid server.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ServerTaskException))]
        public void TestExecuteTaskInvalidServer6()
        {
            TestFrameworkTestHelper.LoadServerAppTestTask("invalid_task6.xml").Execute();
        }
    }

}
