/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NUnit.Framework;
using NAnt.Core;
using NAnt.Core.Types;
using TopCoder.Test.Framework.Servers;
using TopCoder.Test.Framework.Servers.Web;
namespace TopCoder.Test.Framework
{

    /// <summary>
    /// Unit test class for <c>ServerElement</c> class.
    /// </summary>
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class ServerElementTest
    {

        /// <summary>
        /// Private <c>ServerElement</c> variable used for test.
        /// </summary>
        private ServerElement element;

        /// <summary>
        /// Sets up the test environment. A valid <c>ServerElement</c> object is created.
        /// </summary>
        [SetUp]
        protected void SetUp()
        {
            element = new ServerElement();
        }

        /// <summary>
        /// Tests accuracy of constructor <c>ServerElement()</c> of <c>ServerElement</c> class.
        /// The fields should be initialized properly.
        /// </summary>
        [Test]
        public void TestServerElementAccuracy()
        {
            Assert.IsNull(element.ClassName, "ClassName should be set as null.");
            Assert.IsTrue(element.StartServer, "StartServer should be set as true.");
            Assert.IsTrue(element.InitServer, "InitServer should be set as true.");
            Assert.IsNotNull(element.Options, "Options should be set as non-null.");
            Assert.IsNotNull(element.Credentials, "Credentials should be set as non-null.");
            Assert.IsNotNull(element.SourceFiles, "SourceFiles should be set as non-null.");
        }

        /// <summary>
        /// Tests inheritance of constructor <c>ServerElement()</c> of <c>ServerElement</c> class.
        /// <c>ServerElement</c> class should be inherited from <c>Element</c> class.
        /// </summary>
        [Test]
        public void TestServerElementInheritance()
        {
            Assert.IsTrue(((object)element) is Element,
                "ServerElement class should be inherited from Element class.");
        }


        /// <summary>
        /// Tests accuracy of <c>ClassName</c> getter property of <c>ServerElement</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestClassNameGetterAccuracyNull()
        {
            element.ClassName = null;
            Assert.IsNull(element.ClassName, "ClassName should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>ClassName</c> getter property of <c>ServerElement</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestClassNameGetterAccuracyNonNull()
        {
            element.ClassName = "class name";
            Assert.AreEqual("class name", element.ClassName, "ClassName should be correct.");
        }

        /// <summary>
        /// Tests accuracy of <c>ClassName</c> setter property of <c>ServerElement</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestClassNameSetterAccuracyNull()
        {
            element.ClassName = null;
            Assert.IsNull(element.ClassName, "ClassName should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>ClassName</c> setter property of <c>ServerElement</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestClassNameSetterAccuracyNonNull()
        {
            element.ClassName = "class name";
            Assert.AreEqual("class name", element.ClassName, "ClassName should be set correctly.");
        }


        /// <summary>
        /// Tests accuracy of <c>StartServer</c> getter property of <c>ServerElement</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestStartServerGetterAccuracyTrue()
        {
            Assert.IsTrue(element.StartServer, "StartServer should be true.");
        }

        /// <summary>
        /// Tests accuracy of <c>StartServer</c> getter property of <c>ServerElement</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestStartServerGetterAccuracyFalse()
        {
            element.StartServer = false;
            Assert.IsFalse(element.StartServer, "StartServer should be false.");
        }

        /// <summary>
        /// Tests accuracy of <c>StartServer</c> setter property of <c>ServerElement</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestStartServerSetterAccuracyFalse()
        {
            element.StartServer = false;
            Assert.IsFalse(element.StartServer, "StartServer should be set as false.");
        }

        /// <summary>
        /// Tests accuracy of <c>StartServer</c> setter property of <c>ServerElement</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestStartServerSetterAccuracyTrue()
        {
            element.StartServer = true;
            Assert.IsTrue(element.StartServer, "StartServer should be set as true.");
        }


        /// <summary>
        /// Tests accuracy of <c>InitServer</c> getter property of <c>ServerElement</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestInitServerGetterAccuracyTrue()
        {
            Assert.IsTrue(element.InitServer, "InitServer should be true.");
        }

        /// <summary>
        /// Tests accuracy of <c>InitServer</c> getter property of <c>ServerElement</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestInitServerGetterAccuracyFalse()
        {
            element.InitServer = false;
            Assert.IsFalse(element.InitServer, "InitServer should be false.");
        }

        /// <summary>
        /// Tests accuracy of <c>InitServer</c> setter property of <c>ServerElement</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestInitServerSetterAccuracyFalse()
        {
            element.InitServer = false;
            Assert.IsFalse(element.InitServer, "InitServer should be set as false.");
        }

        /// <summary>
        /// Tests accuracy of <c>InitServer</c> setter property of <c>ServerElement</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestInitServerSetterAccuracyTrue()
        {
            element.InitServer = true;
            Assert.IsTrue(element.InitServer, "InitServer should be set as true.");
        }


        /// <summary>
        /// Tests accuracy of <c>Credentials</c> getter property of <c>ServerElement</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestCredentialsGetterAccuracyNull()
        {
            element.Credentials = null;
            Assert.IsNull(element.Credentials, "Credentials should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Credentials</c> getter property of <c>ServerElement</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestCredentialsGetterAccuracyNonNull()
        {
            element.Credentials = new Credential();
            Assert.IsNotNull(element.Credentials, "Credentials should not be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Credentials</c> setter property of <c>ServerElement</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestCredentialsSetterAccuracyNull()
        {
            element.Credentials = null;
            Assert.IsNull(element.Credentials, "Credentials should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Credentials</c> setter property of <c>ServerElement</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestCredentialsSetterAccuracyNonNull()
        {
            element.Credentials = new Credential();
            Assert.IsNotNull(element.Credentials, "Credentials should not be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>SourceFiles</c> getter property of <c>ServerElement</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestSourceFilesGetterAccuracyNull()
        {
            element.SourceFiles = null;
            Assert.IsNull(element.SourceFiles, "SourceFiles should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>SourceFiles</c> getter property of <c>ServerElement</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestSourceFilesGetterAccuracyNonNull()
        {
            element.SourceFiles = new FileSet();
            Assert.IsNotNull(element.SourceFiles, "SourceFiles should not be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>SourceFiles</c> setter property of <c>ServerElement</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestSourceFilesSetterAccuracyNull()
        {
            element.SourceFiles = null;
            Assert.IsNull(element.SourceFiles, "SourceFiles should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>SourceFiles</c> setter property of <c>ServerElement</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestSourceFilesSetterAccuracyNonNull()
        {
            element.SourceFiles = new FileSet();
            Assert.IsNotNull(element.SourceFiles, "SourceFiles should not be null.");
        }


        /// <summary>
        /// Tests accuracy of <c>GetServerInstance()</c> method of <c>ServerElement</c> class.
        /// Class is invalid, ServerException should be thrown.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ServerException))]
        public void TestGetServerInstanceInvalidClass1()
        {

            TestFrameworkTestHelper.LoadServerElement("invalid_server6.xml").GetServerInstance();
        }

        /// <summary>
        /// Tests accuracy of <c>GetServerInstance()</c> method of <c>ServerElement</c> class.
        /// Class is invalid, ServerException should be thrown.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ServerException))]
        public void TestGetServerInstanceInvalidClass2()
        {

            TestFrameworkTestHelper.LoadServerElement("invalid_server7.xml").GetServerInstance();
        }

        /// <summary>
        /// Tests accuracy of <c>GetServerInstance()</c> method of <c>ServerElement</c> class.
        /// Class is invalid, ServerException should be thrown.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ServerException))]
        public void TestGetServerInstanceInvalidClass3()
        {

            TestFrameworkTestHelper.LoadServerElement("invalid_server8.xml").GetServerInstance();
        }

        /// <summary>
        /// Tests accuracy of <c>GetServerInstance()</c> method of <c>ServerElement</c> class.
        /// </summary>
        [Test]
        public void TestGetServerInstanceAccuracy1()
        {
            ServerElement element = TestFrameworkTestHelper.LoadServerElement("iisserver3.xml");

            IISServer server = (IISServer) element.GetServerInstance();

            Assert.AreEqual(element.StartServer, server.StartServer, "wrong StartServer");
            Assert.AreEqual(element.InitServer, server.InitServer, "wrong InitServer");
            Assert.AreEqual(element.Options, server.Options, "wrong Options");
            Assert.AreEqual(element.Project, server.Project, "wrong Project");
            Assert.AreEqual(element.Credentials, server.Credentials, "wrong Credentials");
            Assert.AreEqual(element.SourceFiles, server.SourceFiles, "wrong SourceFiles");

        }

        /// <summary>
        /// Tests accuracy of <c>GetServerInstance()</c> method of <c>ServerElement</c> class.
        /// </summary>
        [Test]
        public void TestGetServerInstanceAccuracy2()
        {
            ServerElement element = TestFrameworkTestHelper.LoadServerElement("database_server.xml");

            DatabaseServer server = (DatabaseServer)element.GetServerInstance();

            Assert.AreEqual(element.StartServer, server.StartServer, "wrong StartServer");
            Assert.AreEqual(element.InitServer, server.InitServer, "wrong InitServer");
            Assert.AreEqual(element.Options, server.Options, "wrong Options");
            Assert.AreEqual(element.Project, server.Project, "wrong Project");
            Assert.AreEqual(element.Credentials, server.Credentials, "wrong Credentials");
            Assert.AreEqual(element.SourceFiles, server.SourceFiles, "wrong SourceFiles");

        }
    }

}

